# -*- coding: utf-8 -*-
#
# Copyright (C) 2010 John Paulett (john -at- paulett.org)
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution.
from django.template import Context, loader, RequestContext

def render(template, context, request=None):
    """Helper function for rendering a template given a context.
    Useful in custom template tags.  The template is the typical path to the
    template file (e.g. 'registration/login.html').  The context is a dictionary
    of data to provide the template.

    If the optional :class:`django.http.HttpRequest`, ``request``, is provided, the
    function will render the template using a :class:`django.template.RequestContext`.
    """
    
    t = loader.get_template(template)
    if request is None:
        c = Context(context)
    else:
        c = RequestContext(context)
    return t.render(c)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2010 John Paulett (john -at- paulett.org)
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution.

from mercurial import hg, ui
from django.conf import settings

def vcs(request):
    """Provide template tags for information about a Mercurial repository.

    Useful if you wish to display the current version of the code. Requires the
    template to be generated with a :class:`django.template.RequestContext` object.
    Provides two template tags, ``rev`` and ``tag``.

    From :file:`settings.py` reads the ``REPO_DIR`` variable (defaults to ``.``),
    which specifies the root of the Mercurial repository.
    """
    repo_dir = settings.REPO_DIR if hasattr(settings, 'REPO_DIR') else '.'
    repo = hg.repository(ui.ui(), repo_dir)
    ctx = repo.changectx(repo.changelog.tip())
    return {'tag': ctx.tags()[0],
            'rev': ctx.rev()}



# -*- coding: utf-8 -*-
#
# Copyright (C) 2010 John Paulett (john -at- paulett.org)
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution.

from django.shortcuts import render_to_response
from django.template import RequestContext

def render_response(request, *args, **kwargs):
    """Adds the RequestContext to django.shortcuts.render_to_response."""
    kwargs['context_instance'] = RequestContext(request)
    return render_to_response(*args, **kwargs)



from distutils.core import setup

import beehat

setup(
    name = 'django-beehat',
    version = beehat.__version__,
    packages = ['beehat'],
    author = 'John Paulett',
    author_email = 'john@paulett.org',
    description = 'Common Django snippets and other useful code.',
    #long_description = jsonpickle.__doc__,
    license = 'BSD',
    keywords = 'django',
    url = 'http://johnpaulett.bitbucket.org/django-beehat/',
)
